---
title: '[공지] 페이코 결제 장애 종결(정상화)'
category: 공지사항
tags:
  - 페이코
  - 공지사항
datetime: 2023-10-23T15:00:00.000Z
---

안녕하세요, 포트원 고객지원팀입니다.

2023년 10월 24일(금일) 오전 9시부터 페이코 내부적으로 장애가 발생된 것으로 전달받아 참고차 공유/안내드립니다.

아래 내용 참고하시어 운영간 차질 없으시기 바랍니다.감사합니다.

---

#### 페이코 추가 공지사항

금일 발생된 페이코 장애는 10시 33분 부로 정상화 반영 되어 내용 공유 드립니다.

■ 장애 시각 : 10/24  09:02\~10:33 (1시간 31분)

■ 장애 영향 : 페이코 신용카드 결제 간헐적 실패 발생

■ 처리 현황 : 배포 및 정상화 완료

■ 향후 방안 : 제휴사에 영향 없도록 모니터링 강화서비스 이용에 불편을 드려 죄송합니다.앞으로 모니터링 강화를 통해 동일한 이슈 없도록 대응하겠습니다.페이코 드림

앞으로 모니터링 강화를 통해 동일한 이슈 없도록 대응하겠습니다.

페이코 드림

---
